is_computed_field

Function is_computed_field 

pub fn is_computed_field(field: &Field) -> bool
True for a field carrying either spelling of @computed — bare or @computed(params: <Type>?). See is_computed_attribute for why this must be the only place the string comparison is written.